==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/PrivateKeyUsagePeriod.h <==
// public class gnu.java.security.x509.ext.PrivateKeyUsagePeriod

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class abe4701a740dc159 gnu_java_security_x509_ext_PrivateKeyUsagePeriod
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_PrivateKeyUsagePeriod_H_
#define _JC_gnu_java_security_x509_ext_PrivateKeyUsagePeriod_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_refs	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_nonrefs	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$refs	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$refs;
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$nonrefs	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object;

typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$fields_struct	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vmethods	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtable	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24PrivateKeyUsagePeriod;
};
extern _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$fields_struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_java_util_Date$object *_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$getNotAfter$c21bf4907f146880(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *);
extern struct _jc_java_util_Date$object *_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$getNotBefore$b09cc63ee770968e(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method_info$getNotAfter$c21bf4907f146880;
extern _jc_method _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method_info$getNotBefore$b09cc63ee770968e;
extern _jc_method _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vmethods {
	struct _jc_java_util_Date$object	*(*getNotAfter$c21bf4907f146880)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *);
	struct _jc_java_util_Date$object	*(*getNotBefore$b09cc63ee770968e)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vmethods	gnu_java_security_x509_ext_PrivateKeyUsagePeriod;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_refs {
	struct _jc_java_util_Date$object	*notBefore;
	struct _jc_java_util_Date$object	*notAfter;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$refs {
    _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_refs	gnu_java_security_x509_ext_PrivateKeyUsagePeriod;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_nonrefs	gnu_java_security_x509_ext_PrivateKeyUsagePeriod;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object {
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_PrivateKeyUsagePeriod, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_PrivateKeyUsagePeriod_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/PrivateKeyUsagePeriod.h <==
// public class gnu.java.security.x509.ext.PrivateKeyUsagePeriod

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 26b081454cf4c042 gnu_java_security_x509_ext_PrivateKeyUsagePeriod
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_PrivateKeyUsagePeriod_H_
#define _JC_gnu_java_security_x509_ext_PrivateKeyUsagePeriod_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_refs	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_nonrefs	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$refs	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$refs;
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$nonrefs	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object;

typedef struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$fields_struct	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vmethods	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtable	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24PrivateKeyUsagePeriod;
};
extern _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$fields_struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_Date$object *_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$getNotAfter$c21bf4907f146880(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_Date$object *_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$getNotBefore$b09cc63ee770968e(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method_info$getNotAfter$c21bf4907f146880;
extern _jc_method _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method_info$getNotBefore$b09cc63ee770968e;
extern _jc_method _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vmethods {
	struct _jc_java_util_Date$object	*(*getNotAfter$c21bf4907f146880)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_Date$object	*(*getNotBefore$b09cc63ee770968e)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vmethods	gnu_java_security_x509_ext_PrivateKeyUsagePeriod;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_refs {
	struct _jc_java_util_Date$object	*notBefore;
	struct _jc_java_util_Date$object	*notAfter;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$refs {
    _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_refs	gnu_java_security_x509_ext_PrivateKeyUsagePeriod;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$sub_nonrefs	gnu_java_security_x509_ext_PrivateKeyUsagePeriod;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$object {
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$vtype _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_PrivateKeyUsagePeriod, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_PrivateKeyUsagePeriod$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_PrivateKeyUsagePeriod_H_ */
